@@ -468,8 +468,9 @@ async def mikrotik_api_probe(host, mikrotik_api_cls, creds, **kwargs):
 async def _ssh_probe(host, port, ssh_client_cls, creds, raise_errors, **kwargs):
     """Probe the SSL server of a host using (username, password) tuples."""
     client = None
-    err = None
+    last_err = None
     for cred in creds:
+        last_err = None
         ssh_client = ssh_client_cls(host,
                                     port=port,
                                     username=cred[0],
@@ -480,15 +481,17 @@ async def _ssh_probe(host, port, ssh_client_cls, creds, raise_errors, **kwargs):
             client = ssh_client
             break
         except asyncssh.PermissionDenied as err:
+            last_err = err
             await ssh_client.close()
         except (asyncssh.Error, OSError, asyncio.TimeoutError) as err:
+            last_err = err
             await ssh_client.close()
             break  # connectivity error, no point in trying other creds
         except Exception:
             await ssh_client.close()
             raise
-    if err and raise_errors:
-        raise err
+    if last_err and raise_errors:
+        raise last_err
     return client
 
 
